狩猎 (豆瓣)
Description: 狩猎电影简介和剧情介绍,狩猎影评、图片、预告片、影讯、论坛、在线购票
Keywords: 狩猎,Jagten,狩猎影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.97豆瓣电影Top250

# 狩猎 Jagten (2012)

导演: 托马斯·温特伯格
编剧: 托马斯·温特伯格 / 托比亚斯·林道赫姆
主演: 麦斯·米科尔森 / 托玛斯·博·拉森 / 安妮卡·韦德科普 / 拉丝·弗格斯托姆 / 苏西·沃德 / 安妮·路易丝·哈辛 / 拉斯·兰特 / 亚历山德拉·拉帕波特
类型: 剧情
制片国家/地区: 丹麦 / 瑞典
语言: 丹麦语 / 英语 / 波兰语
上映日期: 2012-05-20(戛纳电影节) / 2013-01-10(丹麦)
片长: 115分钟 / 110分钟
又名: 诬网(港) / 谎言的烙印(台) / 捕猎 / The Hunt
IMDb: tt2106476
豆瓣评分
引用
9.1
367337人评价
5星
62.7%
4星
31.3%
3星
5.3%
2星
0.4%
1星
0.3%
好于 98% 剧情片
想看 看过
评价:
推荐

## 狩猎的剧情简介 · · · · · ·

刚刚和妻子离婚的卢卡斯（麦斯·米科尔森 Mads Mikkelsen 饰）目前在一家托儿所工作，心地善良个性温和的他很快就受到了同事和孩子们的喜爱，其中，一个名叫卡拉（安妮卡·韦德科普 Annika Wedderkopp 饰）的早熟女孩对卢卡斯尤为的亲近。面对女孩幼稚 而单纯的示好，卢卡斯只能婉转的拒绝，可令他没有想到的是，这一举动将他的生活推向了风口浪尖。
卡拉报复性的谎言让卢卡斯背负起了性侵女童的罪名，一时间，这个好好先生成为了整个小镇排挤和压迫的对象。好友的愤怒，前妻的不信任，爱犬的死亡和陌生人的恶意让卢卡斯几近崩溃，而当小小的卡拉吐露真相之后，恶意却并没有随着卢卡斯的重获清白而划下句点。 ©豆瓣

## 狩猎的演职员 · · · · · · ( 全部 14 )

- 托马斯·温特伯格 导演
- 麦斯·米科尔森 演员
- 托玛斯·博·拉森 演员
- 安妮卡·韦德科普 饰 Klara
- 拉丝·弗格斯托姆 演员
- 苏西·沃德 演员

## 狩猎的视频和图片 · · · · · · ( 预告片4 | 添加视频评论 | 图片609 · 添加 )

## 狩猎的获奖情况 · · · · · · ( 全部 )

- 第86届奥斯卡金像奖
- 最佳外语片(提名)
- 托马斯·温特伯格

- 第65届戛纳电影节
- 主竞赛单元 金棕榈奖(提名)
- 托马斯·温特伯格

- 第71届金球奖
- 电影类 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  控方证人

  记忆碎片

  看不见的客人

  禁闭岛

  致命魔术

  追随

  非常嫌疑犯

  杀人回忆

  大卫·戈尔的一生

  蝴蝶效应

我要写短评

## 狩猎的短评 · · · · · · ( 全部 109133 条 )

热门 / 最新 / 好友

### 10821 有用 麻绳 看过 2013-03-28 16:26:59

这电影要是早两年看，不会有这么深感触。很多情况下，真相是什么对围观者并不重要，他们需要的只是一个支点，让自己站在虚妄的道德制高点上，得意一时是一时，反正过几天他们就会遗忘，任由真相被新的猎奇淹没，微博上这样的人和事比比皆是。

### 6146 有用 柏林苍穹下 看过 2013-03-24 03:09:56

占据道德的制高点猎杀他者，你手上可有血污！？

### 4872 有用 wino 看过 2013-03-22 18:10:35

1.萝莉由爱生怨的报复手段又狠又蠢 2.孩子最可怕就在于明明无知，却会本能地以纯真作为武器，让他人深信不疑 3.人们习惯于自以为是，站在弱者角度分发所谓的正义和怜悯心，本身就是一种不公 4.信任和声誉一样，一旦破坏就无法修复 5.你永远活在他人的目光里，而世界本就有太多恶意~结局很现实，好片

### 4082 有用 cancel 看过 2014-05-23 11:51:03

如果你有个上幼儿园的孩子，就会明白，大多数情况下，通过诱导的方式，成人都能从孩子的口中得到他们想要得到的信息，所以，关键问题是大人们想得到什么，而不是孩子说了什么

### 7620 有用 文西 看过 2012-09-03 15:37:12

其实小孩子最邪恶，因为他们完全不知道行动的后果。

> 更多短评 109133条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 狩猎的影评 · · · · · · ( 全部 2314 条 )

热门 / 最新 / 好友
安德烈大叔 2013-03-22 23:28:14

## 服下这剂恶意，让戾气郁结成冰

一部寒冷彻骨的电影。不温不火的叙事和冷静理智镜头之中酝酿了近乎绝望的压抑、狂躁与寒冷，这部丹麦电影就像北欧的冬天一样寒冷，在颤栗中毫不留情的在人性与社会道德划上深入骨头的一刀。 这部电影的观影过程绝对不是一个愉快的过程，片中酝酿的一种冷而近乎... (展开)
7719 336 673回应 收起
PsychoBabble 2013-03-26 06:17:30

## 社会、普遍价值观、人性

这篇影评可能有剧透

这部丹麦影片《狩猎》，在戛纳电影节上获得了不少好评，同时也成为竞争金棕榈呼声最高的影片之一。 基调比较压抑，沉稳略带写实的摄影风格也体现了这一点，剧情在缓慢的节奏中层层推进，也几乎没有什么配乐，只是靠着导演运筹帷幄的镜头语言和演员们精彩演绎（尤其是主角麦德... (展开)
1901 119 163回应 收起
内个死猴子 2013-05-20 11:28:25

## 君生我未生，我生君已老，君又境界高，不肯跟我好。——《狩猎》拉片分析

这篇影评可能有剧透

看了几个夸奖的影评，以分析社会意义为主，属于马屁拍在马腿。而专黑此片的几个朋友主要黑了三点：1是开头铺垫多，节奏拖沓。2是风格不统一，一会冷，一会温。3是社会意义太强烈以至于降低了艺术性，或曰电影性，有高端冷艳影迷称之为cinematic。其中第3点，是一般冷艳高端... (展开)
1625 643 221回应 收起
木卫二 2013-05-03 13:12:26

## 当你成为猎物

《狩猎》是一部虐片，没有血浆暴力，而是虐心的虐。在我看来，影片也像达内兄弟和李沧东的混合物。儿子反抗和平安夜教堂段落，剧中人物遭遇都让人有一种心口被击中的猛烈震撼。这些悲伤或绝望的故事起始平静，貌似一马平川，前方一览无遗，然而恰是雪崩前的屏息，是冰川开裂前... (展开)
784 85 78回应 收起
süden 2013-07-19 16:57:38

## 白莲花

这篇影评可能有剧透

一、童言无忌 看完片子之后我想到自己的一件小事。 儿子上幼儿园时两岁半，他讲话晚，时常说不清楚发生过什么事。有一天回家洗澡时，发现鸡鸡和周围都长了很多红色的小包，我问他中午睡觉是不是尿床了？他说是。我再问，包什么时候长的？他回答睡觉起来。我给他擦了点药膏止... (展开)
705 20 48回应 收起
麋鹿橙 2013-04-09 00:24:57

## 关于人性，你必须读这样一个故事

村上春树——《沉默》 我问大泽过去他吵架时打过谁没有。 　　 大泽仿佛看什么刺眼东西似地眯细眼睛注视着我。 　　 “怎么问起这个来了呢？”他说。 　　 那眼神无论怎么看都不像平时的他，其中有一种活生生的东西放射着尖刺刺的光。但那也仅限于一瞬之间，他迅速把光收回，... (展开)
664 35 41回应 收起
比多 2013-04-29 23:51:54

## 为什么要废除死刑

1. 《狩猎》放了很久，一直没看。《虐童疑云》和《水果硬糖》也是，我对涉及猥亵儿童的片子有天然的反感。但是我非常喜欢麦德斯·米科尔森的表演，这迫使我把《狩猎》看了。看完之后我突然意识到，我对此类题材的“天然反感”实际上也是一种先入为主的屏蔽。这“天然反感”的危... (展开)
484 54 85回应 收起
睡在巴西旁边 2015-10-31 19:07:09

## 从脚底冷到头皮

人生真的很残酷，善良的人注定会杯具，因为他连感知仇恨和积怨的权利都已丧失。 本片男主人公卢卡斯就是这样一个彻头彻尾的杯具，他就像一颗荒野中的树，孤独而又无法逃避任何来自天空的击打。观影时的这种战栗感就像让你吃了一勺芥末再裹上一嘴滚烫的开水般麻木恶辣。 导演... (展开)
137 11 16回应 收起
简单心理 2017-11-10 14:10:07

## 毁掉一个人需要做些什么？

这篇影评可能有剧透

孩子是社会中特殊的弱势群体，身心皆不成熟。一旦发生疑似伤害孩子的事情，整个社会总是会毫无保留的站在孩子一边，对施害者群起攻之。 但倘若这种毫无保留的道德指责被误用，对一个人的伤害就是毁灭性的。丹麦电影《狩猎》讲述的就是这样一个让人深感寒冷绝望的故事。 刚刚离... (展开)
253 7 31回应 收起
回望长安已苍老 2016-03-17 17:50:36

## 在寒风四起的猎场，像一只仓惶的鹿

帝都，周四，霾。 呼吸困难的空气，心塞胸闷的观影体验，完美自虐的下午。 问：毁掉一个人需要做些什么？ 答：让一个孩子，说一句谎话。 小女孩孤独沉静，渴望关心却不懂好意，随处听来的一句荤话就着不明就里的报复之心轻飘飘地说出口，如石子投进池塘，一圈圈涟漪散开，猝... (展开)
99 4 10回应 收起

> 更多影评 2314篇

添加新讨论

## 讨论区 · · · · · ·

已阅，分~亨~~ | 来自周公子 | 11 回应 | 2022-11-20 00:47:11
看到大家那么骂小女孩，心中拔凉拔凉的。电影白看... | 来自铁蒺藜骨朵 | 78 回应 | 2022-11-17 21:53:35
怎样做才能不冤枉一个好人，又不放过一个坏人？ | 来自zcl91368 | 3 回应 | 2022-11-15 16:47:47
这个园长虽然处理的可能很有问题，但她还是很好地... | 来自a_a | 167 回应 | 2022-11-13 18:32:40
超市可以不允许某个人购物吗？ | 来自jx215 | 6 回应 | 2022-11-13 18:15:38

> 去这部影片的讨论区（全部463条）

## 关于《狩猎》的问题 · · · · · · ( 全部94个 )

- 影片开头是否合乎情理？ 23人回答
- 片中小女孩不走网状的地板，有什么寓意吗？ 19人回答

> 全部94个问题

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 2013 豆瓣电影【口碑榜】 (影志)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)
- 【孤独的人】 (影志)
- 2012新电影（这些，可以期待） (桃桃林林)

## 谁在看这部电影 · · · · · ·

- keo
  2分钟前 想看
- 杨坚强
  5分钟前 看过
- upppppp
  5分钟前 看过

504812人看过 / 431810人想看

订阅狩猎的评论:
feed: rss 2.0